@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,23 +9,24 @@
 #include "archivemailagentutil.h"
 #include "archivemailkernel.h"
 
-#include <KIO/OpenUrlJob>
 #include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 
 #include "kmail-version.h"
 
-#include <MailCommon/MailUtil>
 #include <MailCommon/MailKernel>
+#include <MailCommon/MailUtil>
 
-#include <QLocale>
-#include <KLocalizedString>
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <KMessageBox>
-#include <QMenu>
 #include <KAboutData>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
+#include <QLocale>
+#include <QMenu>
 
-namespace {
+namespace
+{
 inline QString archiveMailCollectionPattern()
 {
     return QStringLiteral("ArchiveMailCollection \\d+");
@@ -58,10 +59,10 @@ ArchiveMailWidget::ArchiveMailWidget(const KSharedConfigPtr &config, QWidget *pa
     : Akonadi::AgentConfigurationBase(config, parent, args)
 {
     ArchiveMailKernel *archiveMailKernel = ArchiveMailKernel::self();
-    CommonKernel->registerKernelIf(archiveMailKernel);   //register KernelIf early, it is used by the Filter classes
-    CommonKernel->registerSettingsIf(archiveMailKernel);   //SettingsIf is used in FolderTreeWidget
+    CommonKernel->registerKernelIf(archiveMailKernel); // register KernelIf early, it is used by the Filter classes
+    CommonKernel->registerSettingsIf(archiveMailKernel); // SettingsIf is used in FolderTreeWidget
 
-    QWidget *w = new QWidget(parent);
+    auto w = new QWidget(parent);
     mWidget.setupUi(w);
     parent->layout()->addWidget(w);
 
@@ -74,8 +75,7 @@ ArchiveMailWidget::ArchiveMailWidget(const KSharedConfigPtr &config, QWidget *pa
     mWidget.treeWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
     mWidget.treeWidget->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    connect(mWidget.treeWidget, &QWidget::customContextMenuRequested,
-            this, &ArchiveMailWidget::slotCustomContextMenuRequested);
+    connect(mWidget.treeWidget, &QWidget::customContextMenuRequested, this, &ArchiveMailWidget::slotCustomContextMenuRequested);
 
     connect(mWidget.removeItem, &QAbstractButton::clicked, this, &ArchiveMailWidget::slotRemoveItem);
     connect(mWidget.modifyItem, &QAbstractButton::clicked, this, &ArchiveMailWidget::slotModifyItem);
@@ -85,23 +85,20 @@ ArchiveMailWidget::ArchiveMailWidget(const KSharedConfigPtr &config, QWidget *pa
     connect(mWidget.treeWidget, &QTreeWidget::itemDoubleClicked, this, &ArchiveMailWidget::slotModifyItem);
     updateButtons();
 
-    KAboutData aboutData(
-        QStringLiteral("archivemailagent"),
-        i18n("Archive Mail Agent"),
-        QStringLiteral(KDEPIM_VERSION),
-        i18n("Archive emails automatically."),
-        KAboutLicense::GPL_V2,
-        i18n("Copyright (C) 2014-2020 Laurent Montel"));
-    aboutData.addAuthor(i18n("Laurent Montel"),
-                        i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+    KAboutData aboutData(QStringLiteral("archivemailagent"),
+                         i18n("Archive Mail Agent"),
+                         QStringLiteral(KDEPIM_VERSION),
+                         i18n("Archive emails automatically."),
+                         KAboutLicense::GPL_V2,
+                         i18n("Copyright (C) 2014-2020 Laurent Montel"));
+    aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
-    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"),
-                            i18nc("EMAIL OF TRANSLATORS", "Your emails"));
+    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
+    aboutData.setProductName(QByteArrayLiteral("Akonadi/Archive Mail Agent"));
     setKAboutData(aboutData);
 }
 
-ArchiveMailWidget::~ArchiveMailWidget()
-= default;
+ArchiveMailWidget::~ArchiveMailWidget() = default;
 
 void ArchiveMailWidget::slotCustomContextMenuRequested(const QPoint &)
 {
@@ -135,7 +132,7 @@ void ArchiveMailWidget::updateButtons()
 
 void ArchiveMailWidget::needReloadConfig()
 {
-    //TODO add messagebox which informs that we save settings here.
+    // TODO add messagebox which informs that we save settings here.
     mWidget.treeWidget->clear();
     load();
 }
@@ -149,7 +146,7 @@ void ArchiveMailWidget::load()
     const int numberOfCollection = collectionList.count();
     for (int i = 0; i < numberOfCollection; ++i) {
         KConfigGroup collectionGroup = config()->group(collectionList.at(i));
-        auto *info = new ArchiveMailInfo(collectionGroup);
+        auto info = new ArchiveMailInfo(collectionGroup);
         if (info->isValid()) {
             createOrUpdateItem(info);
         } else {
@@ -206,7 +203,7 @@ bool ArchiveMailWidget::save() const
 
     const int numberOfItem(mWidget.treeWidget->topLevelItemCount());
     for (int i = 0; i < numberOfItem; ++i) {
-        auto *mailItem = static_cast<ArchiveMailItem *>(mWidget.treeWidget->topLevelItem(i));
+        auto mailItem = static_cast<ArchiveMailItem *>(mWidget.treeWidget->topLevelItem(i));
         if (mailItem->info()) {
             KConfigGroup group = config()->group(ArchiveMailAgentUtil::archivePattern.arg(mailItem->info()->saveCollectionId()));
             mailItem->info()->writeConfig(group);
@@ -241,7 +238,7 @@ void ArchiveMailWidget::slotModifyItem()
         if (!item) {
             return;
         }
-        auto *archiveItem = static_cast<ArchiveMailItem *>(item);
+        auto archiveItem = static_cast<ArchiveMailItem *>(item);
         QPointer<AddArchiveMailDialog> dialog = new AddArchiveMailDialog(archiveItem->info(), parentWidget());
         if (dialog->exec()) {
             ArchiveMailInfo *info = dialog->info();
@@ -273,7 +270,7 @@ bool ArchiveMailWidget::verifyExistingArchive(ArchiveMailInfo *info) const
 {
     const int numberOfItem(mWidget.treeWidget->topLevelItemCount());
     for (int i = 0; i < numberOfItem; ++i) {
-        auto *mailItem = static_cast<ArchiveMailItem *>(mWidget.treeWidget->topLevelItem(i));
+        auto mailItem = static_cast<ArchiveMailItem *>(mWidget.treeWidget->topLevelItem(i));
         ArchiveMailInfo *archiveItemInfo = mailItem->info();
         if (archiveItemInfo) {
             if (info->saveCollectionId() == archiveItemInfo->saveCollectionId()) {
@@ -292,11 +289,11 @@ void ArchiveMailWidget::slotOpenFolder()
         if (!item) {
             return;
         }
-        auto *archiveItem = static_cast<ArchiveMailItem *>(item);
+        auto archiveItem = static_cast<ArchiveMailItem *>(item);
         ArchiveMailInfo *archiveItemInfo = archiveItem->info();
         if (archiveItemInfo) {
             const QUrl url = archiveItemInfo->url();
-            auto *job = new KIO::OpenUrlJob(url);
+            auto job = new KIO::OpenUrlJob(url);
             job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, parentWidget()));
             job->setRunExecutables(false);
             job->start();
@@ -307,7 +304,7 @@ void ArchiveMailWidget::slotOpenFolder()
 void ArchiveMailWidget::slotItemChanged(QTreeWidgetItem *item, int col)
 {
     if (item) {
-        auto *archiveItem = static_cast<ArchiveMailItem *>(item);
+        auto archiveItem = static_cast<ArchiveMailItem *>(item);
         if (archiveItem->info()) {
             if (col == ArchiveMailWidget::Name) {
                 archiveItem->info()->setEnabled(archiveItem->checkState(ArchiveMailWidget::Name) == Qt::Checked);
