@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef ARCHIVEMAILWIDGET_H
 #define ARCHIVEMAILWIDGET_H
 
-#include "ui_archivemailwidget.h"
 #include "archivemailinfo.h"
+#include "ui_archivemailwidget.h"
 #include <QTreeWidgetItem>
 
 #include <AkonadiCore/AgentConfigurationBase>
@@ -17,7 +17,7 @@ class ArchiveMailItem : public QTreeWidgetItem
 {
 public:
     explicit ArchiveMailItem(QTreeWidget *parent = nullptr);
-    ~ArchiveMailItem();
+    ~ArchiveMailItem() override;
 
     void setInfo(ArchiveMailInfo *info);
     ArchiveMailInfo *info() const;
@@ -33,12 +33,7 @@ public:
     explicit ArchiveMailWidget(const KSharedConfigPtr &config, QWidget *parentWidget, const QVariantList &args);
     ~ArchiveMailWidget() override;
 
-    enum ArchiveMailColumn {
-        Name = 0,
-        LastArchiveDate,
-        NextArchive,
-        StorageDirectory
-    };
+    enum ArchiveMailColumn { Name = 0, LastArchiveDate, NextArchive, StorageDirectory };
 
     Q_REQUIRED_RESULT bool save() const override;
     void load() override;
