@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,7 +23,12 @@ public:
 
 public Q_SLOTS:
     void reload();
-    void addReminder(const QString &messageId, Akonadi::Item::Id messageItemId, const QString &to, const QString &subject, const QDate &followupDate, Akonadi::Item::Id todoId);
+    void addReminder(const QString &messageId,
+                     Akonadi::Item::Id messageItemId,
+                     const QString &to,
+                     const QString &subject,
+                     const QDate &followupDate,
+                     Akonadi::Item::Id todoId);
 
 protected:
     void itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection) override;
