@@ -1,27 +1,28 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "followupremindernoanswerdialog.h"
-#include "followupreminderinfowidget.h"
-#include "followupreminderinfo.h"
 #include "followupreminderagent_debug.h"
+#include "followupreminderinfo.h"
+#include "followupreminderinfowidget.h"
 
 #include <KLocalizedString>
 #include <KSharedConfig>
 
-#include <QLabel>
-#include <QDialogButtonBox>
 #include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
 
-#include "notifications_interface.h" // DBUS-generated
 #include "dbusproperties.h" // DBUS-generated
+#include "notifications_interface.h" // DBUS-generated
 
-namespace {
+namespace
+{
 static constexpr const char s_fdo_notifications_service[] = "org.freedesktop.Notifications";
 static constexpr const char s_fdo_notifications_path[] = "/org/freedesktop/Notifications";
 static constexpr const char DialogGroup[] = "FollowUpReminderNoAnswerDialog";
@@ -34,15 +35,15 @@ FollowUpReminderNoAnswerDialog::FollowUpReminderNoAnswerDialog(QWidget *parent)
     setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
     setAttribute(Qt::WA_DeleteOnClose);
 
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QLabel *lab = new QLabel(i18n("You still wait an answer about this mail:"), this);
+    auto lab = new QLabel(i18n("You still wait an answer about this mail:"), this);
     mainLayout->addWidget(lab);
     mWidget = new FollowUpReminderInfoWidget(this);
     mWidget->setObjectName(QStringLiteral("FollowUpReminderInfoWidget"));
     mainLayout->addWidget(mWidget);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -54,12 +55,14 @@ FollowUpReminderNoAnswerDialog::FollowUpReminderNoAnswerDialog(QWidget *parent)
     readConfig();
     QDBusConnection dbusConn = QDBusConnection::sessionBus();
     if (dbusConn.interface()->isServiceRegistered(QString::fromLatin1(s_fdo_notifications_service))) {
-        OrgFreedesktopDBusPropertiesInterface *propsIface = new OrgFreedesktopDBusPropertiesInterface(
-            QString::fromLatin1(s_fdo_notifications_service),
-            QString::fromLatin1(s_fdo_notifications_path),
-            dbusConn, this);
-        connect(propsIface, &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged,
-                this, &FollowUpReminderNoAnswerDialog::slotDBusNotificationsPropertiesChanged);
+        auto propsIface = new OrgFreedesktopDBusPropertiesInterface(QString::fromLatin1(s_fdo_notifications_service),
+                                                                    QString::fromLatin1(s_fdo_notifications_path),
+                                                                    dbusConn,
+                                                                    this);
+        connect(propsIface,
+                &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged,
+                this,
+                &FollowUpReminderNoAnswerDialog::slotDBusNotificationsPropertiesChanged);
     }
 }
 
@@ -74,10 +77,7 @@ void FollowUpReminderNoAnswerDialog::wakeUp()
     // In that case, we'll wait until they are allowed again (see slotDBusNotificationsPropertiesChanged)
     QDBusConnection dbusConn = QDBusConnection::sessionBus();
     if (dbusConn.interface()->isServiceRegistered(QString::fromLatin1(s_fdo_notifications_service))) {
-        OrgFreedesktopNotificationsInterface iface(
-            QString::fromLatin1(s_fdo_notifications_service),
-            QString::fromLatin1(s_fdo_notifications_path),
-            dbusConn);
+        OrgFreedesktopNotificationsInterface iface(QString::fromLatin1(s_fdo_notifications_service), QString::fromLatin1(s_fdo_notifications_path), dbusConn);
         if (iface.inhibited()) {
             return;
         }
@@ -85,11 +85,12 @@ void FollowUpReminderNoAnswerDialog::wakeUp()
     show();
 }
 
-void FollowUpReminderNoAnswerDialog::slotDBusNotificationsPropertiesChanged(
-    const QString &interface, const QVariantMap &changedProperties, const QStringList &invalidatedProperties)
+void FollowUpReminderNoAnswerDialog::slotDBusNotificationsPropertiesChanged(const QString &interface,
+                                                                            const QVariantMap &changedProperties,
+                                                                            const QStringList &invalidatedProperties)
 {
-    Q_UNUSED(interface); // always "org.freedesktop.Notifications"
-    Q_UNUSED(invalidatedProperties);
+    Q_UNUSED(interface) // always "org.freedesktop.Notifications"
+    Q_UNUSED(invalidatedProperties)
     const auto it = changedProperties.find(QStringLiteral("Inhibited"));
     if (it != changedProperties.end()) {
         const bool inhibited = it.value().toBool();
