@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define FOLLOWUPREMINDERNOANSWERDIALOG_H
 
 #include <QDialog>
-namespace FollowUpReminder {
+namespace FollowUpReminder
+{
 class FollowUpReminderInfo;
 }
 class FollowUpReminderInfoWidget;
@@ -17,7 +18,7 @@ class FollowUpReminderNoAnswerDialog : public QDialog
     Q_OBJECT
 public:
     explicit FollowUpReminderNoAnswerDialog(QWidget *parent = nullptr);
-    ~FollowUpReminderNoAnswerDialog();
+    ~FollowUpReminderNoAnswerDialog() override;
 
     void setInfo(const QList<FollowUpReminder::FollowUpReminderInfo *> &info);
 
