@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef FOLLOWUPREMINDERFINISHTASKJOB_H
 #define FOLLOWUPREMINDERFINISHTASKJOB_H
 
-#include <QObject>
 #include <AkonadiCore/Item>
+#include <QObject>
 class KJob;
 class FollowUpReminderFinishTaskJob : public QObject
 {
     Q_OBJECT
 public:
     explicit FollowUpReminderFinishTaskJob(Akonadi::Item::Id id, QObject *parent = nullptr);
-    ~FollowUpReminderFinishTaskJob();
+    ~FollowUpReminderFinishTaskJob() override;
 
     void start();
 
