@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class FollowUpReminderJob : public QObject
     Q_OBJECT
 public:
     explicit FollowUpReminderJob(QObject *parent = nullptr);
-    ~FollowUpReminderJob();
+    ~FollowUpReminderJob() override;
 
     void setItem(const Akonadi::Item &item);
 
