@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
-    SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-only
 */
@@ -22,7 +22,8 @@ class QPushButton;
   The filter log dialog allows a continued observation of the
   filter log of MailFilterAgent.
 */
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
 
@@ -44,7 +45,7 @@ class FilterLogDialog : public QDialog
 public:
     /** constructor */
     explicit FilterLogDialog(QWidget *parent);
-    ~FilterLogDialog();
+    ~FilterLogDialog() override;
 
 private:
     void slotTextChanged();
