@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define MAILFILTERPURPOSEMENUWIDGET_H
 
 #include <PimCommon/PurposeMenuWidget>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditor;
 }
 class MailfilterPurposeMenuWidget : public PimCommon::PurposeMenuWidget
@@ -20,6 +21,7 @@ public:
 
     Q_REQUIRED_RESULT QByteArray text() override;
     void setEditorWidget(KPIMTextEdit::PlainTextEditor *editor);
+
 private:
     KPIMTextEdit::PlainTextEditor *mEditor = nullptr;
 };
