@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,12 +9,14 @@
 
 #include <KSharedConfig>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class SendLaterInfo;
 }
 
 /** Send later utilities. */
-namespace SendLaterUtil {
+namespace SendLaterUtil
+{
 Q_REQUIRED_RESULT bool compareSendLaterInfo(MessageComposer::SendLaterInfo *left, MessageComposer::SendLaterInfo *right);
 
 Q_REQUIRED_RESULT KSharedConfig::Ptr defaultConfig();
