@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,10 +9,12 @@
 
 #include <QDateTime>
 
-namespace SendLater {
+namespace SendLater
+{
 class SendLaterInfo;
 
-namespace SendLaterUtil {
+namespace SendLaterUtil
+{
 Q_REQUIRED_RESULT QDateTime updateRecurence(SendLater::SendLaterInfo *info, QDateTime dateTime);
 }
 }
