@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,7 @@
 RefreshSettringsFinishPage::RefreshSettringsFinishPage(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
     mainLayout->setContentsMargins({});
 
@@ -22,8 +22,7 @@ RefreshSettringsFinishPage::RefreshSettringsFinishPage(QWidget *parent)
     connect(this, &RefreshSettringsFinishPage::cleanDoneInfo, this, &RefreshSettringsFinishPage::slotCleanDoneInfo);
 }
 
-RefreshSettringsFinishPage::~RefreshSettringsFinishPage()
-= default;
+RefreshSettringsFinishPage::~RefreshSettringsFinishPage() = default;
 
 void RefreshSettringsFinishPage::slotCleanDoneInfo(const QString &str)
 {
