@@ -11,16 +11,16 @@
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#include "ktnefmain.h"
 #include "ktnef-version.h"
+#include "ktnefmain.h"
 
-#include <Kdelibs4ConfigMigrator>
 #include <KAboutData>
-#include <KLocalizedString>
-#include <QCommandLineParser>
-#include <QApplication>
-#include <KDBusService>
 #include <KCrash>
+#include <KDBusService>
+#include <KLocalizedString>
+#include <Kdelibs4ConfigMigrator>
+#include <QApplication>
+#include <QCommandLineParser>
 
 int main(int argc, char *argv[])
 {
@@ -41,15 +41,9 @@ int main(int argc, char *argv[])
                          KAboutLicense::GPL,
                          i18n("Copyright 2000 Michael Goffioul \nCopyright 2012  Allen Winter"));
 
-    aboutData.addAuthor(
-        i18n("Michael Goffioul"),
-        i18n("Author"),
-        QStringLiteral("kdeprint@swing.be"));
+    aboutData.addAuthor(i18n("Michael Goffioul"), i18n("Author"), QStringLiteral("kdeprint@swing.be"));
 
-    aboutData.addAuthor(
-        i18n("Allen Winter"),
-        i18n("Author, Ported to Qt4/KDE4"),
-        QStringLiteral("winter@kde.org"));
+    aboutData.addAuthor(i18n("Allen Winter"), i18n("Author, Ported to Qt4/KDE4"), QStringLiteral("winter@kde.org"));
 
     KAboutData::setApplicationData(aboutData);
 
@@ -63,7 +57,7 @@ int main(int argc, char *argv[])
 
     KDBusService service;
 
-    auto *tnef = new KTNEFMain();
+    auto tnef = new KTNEFMain();
     tnef->show();
     const QStringList &args = parser.positionalArguments();
 
