@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,14 +7,12 @@
 #include "kactionmenutransporttest.h"
 #include "../widgets/kactionmenutransport.h"
 #include <QTest>
-#include <QMenu>
 KActionMenuTransportTest::KActionMenuTransportTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-KActionMenuTransportTest::~KActionMenuTransportTest()
-= default;
+KActionMenuTransportTest::~KActionMenuTransportTest() = default;
 
 void KActionMenuTransportTest::shouldHaveDefaultValue()
 {
