@@ -1,32 +1,32 @@
 /*
  *
  * SPDX-FileCopyrightText: 2006 Till Adam <adam@kde.org>
- * SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #include "collectionquotawidget.h"
 
+#include <KFormat>
 #include <KLocalizedString>
 #include <QGridLayout>
 #include <QLabel>
 #include <QProgressBar>
-#include <KFormat>
 
 CollectionQuotaWidget::CollectionQuotaWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *layout = new QGridLayout(this);
+    auto layout = new QGridLayout(this);
 
-    QLabel *lab = new QLabel(i18n("Usage:"), this);
+    auto lab = new QLabel(i18n("Usage:"), this);
     layout->addWidget(lab, 0, 0);
 
     mUsage = new QLabel(this);
     mUsage->setTextFormat(Qt::PlainText);
     layout->addWidget(mUsage, 0, 1);
 
-    QLabel *Status = new QLabel(i18n("Status:"), this);
+    auto Status = new QLabel(i18n("Status:"), this);
     layout->addWidget(Status, 1, 0);
     mProgressBar = new QProgressBar(this);
     // xgettext: no-c-format
