@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,16 +7,16 @@
 #include "collectionviewpage.h"
 #include <MailCommon/MailKernel>
 
-#include <AkonadiCore/entitydisplayattribute.h>
 #include <Akonadi/KMime/MessageFolderAttribute>
+#include <AkonadiCore/entitydisplayattribute.h>
 
+#include "kmail_debug.h"
+#include <KIconButton>
+#include <KLocalizedString>
+#include <QCheckBox>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QCheckBox>
 #include <QVBoxLayout>
-#include <KLocalizedString>
-#include <KIconButton>
-#include "kmail_debug.h"
 
 #include <MessageList/AggregationComboBox>
 #include <MessageList/AggregationConfigButton>
@@ -34,15 +34,14 @@ CollectionViewPage::CollectionViewPage(QWidget *parent)
     setPageTitle(i18nc("@title:tab View settings for a folder.", "View"));
 }
 
-CollectionViewPage::~CollectionViewPage()
-= default;
+CollectionViewPage::~CollectionViewPage() = default;
 
 void CollectionViewPage::init(const Akonadi::Collection &col)
 {
     mFolderCollection = FolderSettings::forCollection(col);
     mIsLocalSystemFolder = CommonKernel->isSystemFolderCollection(col) || mFolderCollection->isStructural() || Kernel::folderIsInbox(col);
 
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     // Musn't be able to edit details for non-resource, system folder.
     if (!mIsLocalSystemFolder) {
         // icons
@@ -75,7 +74,7 @@ void CollectionViewPage::init(const Akonadi::Collection &col)
         mUnreadIconButton->setIcon(QStringLiteral("folder-open"));
         mUnreadIconButton->setEnabled(false);
 
-        auto *iconHLayout = new QHBoxLayout();
+        auto iconHLayout = new QHBoxLayout();
         iconHLayout->addWidget(mIconsCheckBox);
         iconHLayout->addStretch(2);
         iconHLayout->addWidget(mNormalIconLabel);
