@@ -19,7 +19,7 @@
 ConfigModuleWithTabs::ConfigModuleWithTabs(QWidget *parent)
     : ConfigModule(parent)
 {
-    auto *vlay = new QVBoxLayout(this);
+    auto vlay = new QVBoxLayout(this);
     vlay->setContentsMargins({});
     mTabWidget = new QTabWidget(this);
     vlay->addWidget(mTabWidget);
@@ -28,8 +28,7 @@ ConfigModuleWithTabs::ConfigModuleWithTabs(QWidget *parent)
 void ConfigModuleWithTabs::addTab(ConfigModuleTab *tab, const QString &title)
 {
     mTabWidget->addTab(tab, title);
-    connect(tab, SIGNAL(changed(bool)),
-            this, SIGNAL(changed(bool)));
+    connect(tab, SIGNAL(changed(bool)), this, SIGNAL(changed(bool)));
 }
 
 void ConfigModuleWithTabs::showEvent(QShowEvent *event)
@@ -42,7 +41,7 @@ void ConfigModuleWithTabs::load()
 {
     const int numberOfTab = mTabWidget->count();
     for (int i = 0; i < numberOfTab; ++i) {
-        auto *tab = qobject_cast<ConfigModuleTab *>(mTabWidget->widget(i));
+        auto tab = qobject_cast<ConfigModuleTab *>(mTabWidget->widget(i));
         if (tab) {
             tab->load();
         }
@@ -56,7 +55,7 @@ void ConfigModuleWithTabs::save()
         KCModule::save();
         const int numberOfTab = mTabWidget->count();
         for (int i = 0; i < numberOfTab; ++i) {
-            auto *tab = qobject_cast<ConfigModuleTab *>(mTabWidget->widget(i));
+            auto tab = qobject_cast<ConfigModuleTab *>(mTabWidget->widget(i));
             if (tab) {
                 tab->save();
             }
@@ -66,7 +65,7 @@ void ConfigModuleWithTabs::save()
 
 void ConfigModuleWithTabs::defaults()
 {
-    auto *tab = qobject_cast<ConfigModuleTab *>(mTabWidget->currentWidget());
+    auto tab = qobject_cast<ConfigModuleTab *>(mTabWidget->currentWidget());
     if (tab) {
         tab->defaults();
     }
