@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,22 +7,22 @@
 #include "addemailtoexistingcontactdialog.h"
 #include "kmkernel.h"
 
-#include <Akonadi/Contact/EmailAddressSelectionWidget>
-#include <AkonadiCore/Session>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/EntityDisplayAttribute>
 #include <Akonadi/Contact/ContactsTreeModel>
+#include <Akonadi/Contact/EmailAddressSelectionWidget>
 #include <AkonadiCore/ChangeRecorder>
+#include <AkonadiCore/EntityDisplayAttribute>
+#include <AkonadiCore/ItemFetchScope>
+#include <AkonadiCore/Session>
 
 #include <KContacts/Addressee>
 
 #include <KLocalizedString>
 
-#include <QTreeView>
-#include <QDialogButtonBox>
-#include <QVBoxLayout>
-#include <QPushButton>
 #include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QTreeView>
+#include <QVBoxLayout>
 
 AddEmailToExistingContactDialog::AddEmailToExistingContactDialog(QWidget *parent)
     : QDialog(parent)
@@ -30,30 +30,33 @@ AddEmailToExistingContactDialog::AddEmailToExistingContactDialog(QWidget *parent
     setWindowTitle(i18nc("@title:window", "Select Contact"));
     setModal(true);
 
-    Akonadi::Session *session = new Akonadi::Session("AddEmailToExistingContactDialog", this);
+    auto session = new Akonadi::Session("AddEmailToExistingContactDialog", this);
 
     Akonadi::ItemFetchScope scope;
     scope.fetchFullPayload(true);
     scope.fetchAttribute<Akonadi::EntityDisplayAttribute>();
 
-    auto *changeRecorder = new Akonadi::ChangeRecorder(this);
+    auto changeRecorder = new Akonadi::ChangeRecorder(this);
     changeRecorder->setSession(session);
     changeRecorder->fetchCollection(true);
     changeRecorder->setItemFetchScope(scope);
     changeRecorder->setCollectionMonitored(Akonadi::Collection::root());
-    //Just select address no group
+    // Just select address no group
     changeRecorder->setMimeTypeMonitored(KContacts::Addressee::mimeType(), true);
 
-    auto *model = new Akonadi::ContactsTreeModel(changeRecorder, this);
+    auto model = new Akonadi::ContactsTreeModel(changeRecorder, this);
 
     mEmailSelectionWidget = new Akonadi::EmailAddressSelectionWidget(false, model, this);
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mEmailSelectionWidget);
     mEmailSelectionWidget->view()->setSelectionMode(QAbstractItemView::SingleSelection);
     readConfig();
-    connect(mEmailSelectionWidget->view()->selectionModel(), &QItemSelectionModel::selectionChanged, this, &AddEmailToExistingContactDialog::slotSelectionChanged);
+    connect(mEmailSelectionWidget->view()->selectionModel(),
+            &QItemSelectionModel::selectionChanged,
+            this,
+            &AddEmailToExistingContactDialog::slotSelectionChanged);
     connect(mEmailSelectionWidget->view(), &QTreeView::doubleClicked, this, &AddEmailToExistingContactDialog::slotDoubleClicked);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
