@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,13 +11,14 @@
 class QComboBox;
 class KNotifyConfigWidget;
 
-namespace KMail {
+namespace KMail
+{
 class KMKnotify : public QDialog
 {
     Q_OBJECT
 public:
     explicit KMKnotify(QWidget *parent);
-    ~KMKnotify();
+    ~KMKnotify() override;
 
     void setCurrentNotification(const QString &name);
 
