@@ -1,27 +1,29 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "kmcomposereditorng.h"
+#include "dialog/spellcheckerconfigdialog.h"
+#include "job/dndfromarkjob.h"
+#include "kmail_debug.h"
 #include "kmcomposerwin.h"
 #include "kmkernel.h"
 #include "util.h"
-#include "kmail_debug.h"
-#include "job/dndfromarkjob.h"
-#include "dialog/spellcheckerconfigdialog.h"
 
-#include <QMenu>
-#include <KToggleAction>
-#include <QMimeData>
-#include <QCheckBox>
-#include <MessageCore/MessageCoreSettings>
-#include <Sonnet/ConfigDialog>
 #include <KPIMTextEdit/RichTextComposerEmailQuoteHighlighter>
+#include <KToggleAction>
+#include <MessageCore/ColorUtil>
+#include <MessageCore/MessageCoreSettings>
+#include <QCheckBox>
+#include <QMenu>
+#include <QMimeData>
+#include <Sonnet/ConfigDialog>
 #include <sonnet/dictionarycombobox.h>
 
-namespace {
+namespace
+{
 inline QString textSnippetMimeType()
 {
     return QStringLiteral("text/x-kmail-textsnippet");
@@ -37,12 +39,11 @@ KMComposerEditorNg::KMComposerEditorNg(KMComposerWin *win, QWidget *parent)
     createHighlighter();
 }
 
-KMComposerEditorNg::~KMComposerEditorNg()
-= default;
+KMComposerEditorNg::~KMComposerEditorNg() = default;
 
 void KMComposerEditorNg::addExtraMenuEntry(QMenu *menu, QPoint pos)
 {
-    Q_UNUSED(pos);
+    Q_UNUSED(pos)
     const QList<QAction *> lstAct = mComposerWin->pluginToolsActionListForPopupMenu();
     for (QAction *a : lstAct) {
         menu->addSeparator();
@@ -100,8 +101,7 @@ void KMComposerEditorNg::setHighlighterColors(KPIMTextEdit::RichTextComposerEmai
         color3 = MessageCore::MessageCoreSettings::self()->quotedText3();
     }
 
-    highlighter->setQuoteColor(Qt::black /* ignored anyway */,
-                               color1, color2, color3, misspelled);
+    highlighter->setQuoteColor(Qt::black /* ignored anyway */, color1, color2, color3, misspelled);
 }
 
 QString KMComposerEditorNg::smartQuote(const QString &msg)
@@ -111,7 +111,7 @@ QString KMComposerEditorNg::smartQuote(const QString &msg)
 
 void KMComposerEditorNg::showSpellConfigDialog(const QString &configFileName)
 {
-    Q_UNUSED(configFileName);
+    Q_UNUSED(configFileName)
     QPointer<SpellCheckerConfigDialog> dialog = new SpellCheckerConfigDialog(this);
     if (!spellCheckingLanguage().isEmpty()) {
         dialog->setLanguage(spellCheckingLanguage());
