@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -9,7 +9,8 @@
 
 #include <MessageComposer/RichTextComposerNg>
 class KMComposerWin;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextComposerEmailQuoteHighlighter;
 }
 class KMComposerEditorNg : public MessageComposer::RichTextComposerNg
