@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,17 +7,17 @@
 #ifndef KMCOMPOSERUPDATETEMPLATEJOB_H
 #define KMCOMPOSERUPDATETEMPLATEJOB_H
 
-#include <QObject>
-#include <KMime/Message>
 #include <AkonadiCore/Collection>
 #include <KIdentityManagement/Identity>
+#include <KMime/Message>
+#include <QObject>
 
 class KMComposerUpdateTemplateJob : public QObject
 {
     Q_OBJECT
 public:
     explicit KMComposerUpdateTemplateJob(QObject *parent = nullptr);
-    ~KMComposerUpdateTemplateJob();
+    ~KMComposerUpdateTemplateJob() override;
     void start();
     void setMsg(const KMime::Message::Ptr &msg);
 
