@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,10 +8,12 @@
 #define KMAILPLUGINGrammarEDITORMANAGERINTERFACE_H
 
 #include <QObject>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextComposer;
 }
-namespace PimCommon {
+namespace PimCommon
+{
 class CustomToolsWidgetNg;
 }
 class KActionCollection;
@@ -20,7 +22,7 @@ class KMailPluginGrammarEditorManagerInterface : public QObject
     Q_OBJECT
 public:
     explicit KMailPluginGrammarEditorManagerInterface(QObject *parent = nullptr);
-    ~KMailPluginGrammarEditorManagerInterface() = default;
+    ~KMailPluginGrammarEditorManagerInterface() override = default;
 
     KPIMTextEdit::RichTextComposer *richTextEditor() const;
     void setRichTextEditor(KPIMTextEdit::RichTextComposer *richTextEditor);
