@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,15 +8,15 @@
 #ifndef POTENTIALPHISHINGDETAILDIALOG_H
 #define POTENTIALPHISHINGDETAILDIALOG_H
 
-#include <QDialog>
 #include "kmail_private_export.h"
+#include <QDialog>
 class PotentialPhishingDetailWidget;
 class KMAILTESTS_TESTS_EXPORT PotentialPhishingDetailDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit PotentialPhishingDetailDialog(QWidget *parent = nullptr);
-    ~PotentialPhishingDetailDialog();
+    ~PotentialPhishingDetailDialog() override;
 
     void fillList(const QStringList &lst);
 
