@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef ATTACHMENTADDEDFROMEXTERNALWARNING_H
 #define ATTACHMENTADDEDFROMEXTERNALWARNING_H
 
-#include <QWidget>
 #include <KMessageWidget>
+#include <QWidget>
 
 class AttachmentAddedFromExternalWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit AttachmentAddedFromExternalWarning(QWidget *parent = nullptr);
-    ~AttachmentAddedFromExternalWarning();
+    ~AttachmentAddedFromExternalWarning() override;
 
     void setAttachmentNames(const QStringList &lst);
 };
