@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class AttachmentMissingWarning : public KMessageWidget
     Q_OBJECT
 public:
     explicit AttachmentMissingWarning(QWidget *parent = nullptr);
-    ~AttachmentMissingWarning();
+    ~AttachmentMissingWarning() override;
     void slotFileAttached();
 
 Q_SIGNALS:
