@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef CRYPTOSTATEINDICATORWIDGET_H
 #define CRYPTOSTATEINDICATORWIDGET_H
 
-#include <QWidget>
 #include "kmail_private_export.h"
+#include <QWidget>
 class QLabel;
 
 class KMAILTESTS_TESTS_EXPORT CryptoStateIndicatorWidget : public QWidget
@@ -16,7 +16,7 @@ class KMAILTESTS_TESTS_EXPORT CryptoStateIndicatorWidget : public QWidget
     Q_OBJECT
 public:
     explicit CryptoStateIndicatorWidget(QWidget *parent = nullptr);
-    ~CryptoStateIndicatorWidget();
+    ~CryptoStateIndicatorWidget() override;
 
     void updateSignatureAndEncrypionStateIndicators(bool isSign, bool isEncrypted);
 
@@ -24,8 +24,8 @@ public:
 
 private:
     void updateShowAlwaysIndicator();
-    QLabel *mSignatureStateIndicator = nullptr;
-    QLabel *mEncryptionStateIndicator = nullptr;
+    QLabel *const mSignatureStateIndicator;
+    QLabel *const mEncryptionStateIndicator;
     bool mShowAlwaysIndicator = true;
     bool mIsSign = false;
     bool mIsEncrypted = false;
