@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -15,8 +15,7 @@ IdentityFolderRequester::IdentityFolderRequester(QWidget *parent)
 {
 }
 
-IdentityFolderRequester::~IdentityFolderRequester()
-= default;
+IdentityFolderRequester::~IdentityFolderRequester() = default;
 
 void IdentityFolderRequester::setIsInvalidFolder(const Akonadi::Collection &col)
 {
