@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -9,19 +9,22 @@
 
 #include <MailCommon/FolderRequester>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Collection;
 }
 
-namespace KMail {
+namespace KMail
+{
 class IdentityFolderRequester : public MailCommon::FolderRequester
 {
     Q_OBJECT
 public:
     explicit IdentityFolderRequester(QWidget *parent = nullptr);
-    ~IdentityFolderRequester();
+    ~IdentityFolderRequester() override;
 
     void setIsInvalidFolder(const Akonadi::Collection &col);
+
 private:
     void slotFolderChanged(const Akonadi::Collection &col);
 };
