@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -8,13 +8,14 @@
 #define IDENTITYINVALIDFOLDER_H
 
 #include <KMessageWidget>
-namespace KMail {
+namespace KMail
+{
 class IdentityInvalidFolder : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit IdentityInvalidFolder(QWidget *parent = nullptr);
-    ~IdentityInvalidFolder();
+    ~IdentityInvalidFolder() override;
 
     void setErrorMessage(const QString &msg);
 };
