@@ -1,23 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "createfollowupreminderonexistingmessagejob.h"
 #include "kmail_debug.h"
-#include <MessageComposer/FollowupReminderCreateJob>
 #include <AkonadiCore/ItemFetchJob>
 #include <AkonadiCore/ItemFetchScope>
 #include <KMime/Message>
+#include <MessageComposer/FollowupReminderCreateJob>
 
 CreateFollowupReminderOnExistingMessageJob::CreateFollowupReminderOnExistingMessageJob(QObject *parent)
     : QObject(parent)
 {
 }
 
-CreateFollowupReminderOnExistingMessageJob::~CreateFollowupReminderOnExistingMessageJob()
-= default;
+CreateFollowupReminderOnExistingMessageJob::~CreateFollowupReminderOnExistingMessageJob() = default;
 
 void CreateFollowupReminderOnExistingMessageJob::start()
 {
@@ -31,14 +30,14 @@ void CreateFollowupReminderOnExistingMessageJob::start()
 
 void CreateFollowupReminderOnExistingMessageJob::doStart()
 {
-    auto *job = new Akonadi::ItemFetchJob(mMessageItem, this);
+    auto job = new Akonadi::ItemFetchJob(mMessageItem, this);
     job->fetchScope().fetchFullPayload(true);
     connect(job, &KJob::result, this, &CreateFollowupReminderOnExistingMessageJob::itemFetchJobDone);
 }
 
 void CreateFollowupReminderOnExistingMessageJob::itemFetchJobDone(KJob *job)
 {
-    auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
     if (fetchJob->items().count() == 1) {
         mMessageItem = fetchJob->items().constFirst();
     } else {
@@ -53,7 +52,7 @@ void CreateFollowupReminderOnExistingMessageJob::itemFetchJobDone(KJob *job)
     }
     KMime::Message::Ptr msg = mMessageItem.payload<KMime::Message::Ptr>();
     if (msg) {
-        auto *reminderJob = new MessageComposer::FollowupReminderCreateJob(this);
+        auto reminderJob = new MessageComposer::FollowupReminderCreateJob(this);
         KMime::Headers::MessageID *messageID = msg->messageID(false);
         if (messageID) {
             const QString messageIdStr = messageID->asUnicodeString();
@@ -90,7 +89,7 @@ void CreateFollowupReminderOnExistingMessageJob::slotReminderDone(KJob *job)
     if (job->error()) {
         qCDebug(KMAIL_LOG) << "CreateFollowupReminderOnExistingMessageJob::slotReminderDone  :" << job->errorString();
     } else {
-        //TODO update dialog if opened
+        // TODO update dialog if opened
     }
     deleteLater();
 }
