@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,17 +8,17 @@
 #define CREATEFOLLOWUPREMINDERONEXISTINGMESSAGEJOB_H
 
 #include "kmail_private_export.h"
-#include <QObject>
 #include <AkonadiCore/Collection>
-#include <QDate>
 #include <AkonadiCore/Item>
+#include <QDate>
+#include <QObject>
 
 class KMAILTESTS_TESTS_EXPORT CreateFollowupReminderOnExistingMessageJob : public QObject
 {
     Q_OBJECT
 public:
     explicit CreateFollowupReminderOnExistingMessageJob(QObject *parent = nullptr);
-    ~CreateFollowupReminderOnExistingMessageJob();
+    ~CreateFollowupReminderOnExistingMessageJob() override;
 
     void start();
 
