@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -10,19 +10,20 @@
 
 #include <QObject>
 
-#include <Collection>
 #include <Akonadi/KMime/MarkAsCommand>
+#include <Collection>
 
 class MarkAllMessagesAsReadInFolderAndSubFolderJob : public QObject
 {
     Q_OBJECT
 public:
     explicit MarkAllMessagesAsReadInFolderAndSubFolderJob(QObject *parent = nullptr);
-    ~MarkAllMessagesAsReadInFolderAndSubFolderJob();
+    ~MarkAllMessagesAsReadInFolderAndSubFolderJob() override;
 
     void setTopLevelCollection(const Akonadi::Collection &topLevelCollection);
 
     void start();
+
 private:
     Q_DISABLE_COPY(MarkAllMessagesAsReadInFolderAndSubFolderJob)
     void slotFetchCollectionFailed();
