@@ -1,21 +1,26 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef NEWMESSAGEJOB_H
 #define NEWMESSAGEJOB_H
 
+#include <MailCommon/FolderSettings>
 #include <QObject>
 #include <QSharedPointer>
-#include <MailCommon/FolderSettings>
 
-struct NewMessageJobSettings
-{
-    NewMessageJobSettings()
-    = default;
+struct NewMessageJobSettings {
+    NewMessageJobSettings() = default;
 
-    NewMessageJobSettings(const QString &to, const QString &cc, const QString &bcc, bool hidden, const QString &attachURL, const QSharedPointer<MailCommon::FolderSettings> &folder, uint identity, const Akonadi::Collection &currentCollection)
+    NewMessageJobSettings(const QString &to,
+                          const QString &cc,
+                          const QString &bcc,
+                          bool hidden,
+                          const QString &attachURL,
+                          const QSharedPointer<MailCommon::FolderSettings> &folder,
+                          uint identity,
+                          const Akonadi::Collection &currentCollection)
         : mTo(to)
         , mCc(cc)
         , mBcc(bcc)
@@ -42,7 +47,7 @@ class NewMessageJob : public QObject
     Q_OBJECT
 public:
     explicit NewMessageJob(QObject *parent = nullptr);
-    ~NewMessageJob();
+    ~NewMessageJob() override;
     void start();
 
     void setNewMessageJobSettings(const NewMessageJobSettings &newMessageJobSettings);
