@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef REMOVECOLLECTIONJOB_H
 #define REMOVECOLLECTIONJOB_H
 
-#include <QObject>
 #include <AkonadiCore/Collection>
+#include <QObject>
 class KMMainWidget;
 class KJob;
 class RemoveCollectionJob : public QObject
@@ -16,7 +16,7 @@ class RemoveCollectionJob : public QObject
     Q_OBJECT
 public:
     explicit RemoveCollectionJob(QObject *parent = nullptr);
-    ~RemoveCollectionJob();
+    ~RemoveCollectionJob() override;
 
     void setMainWidget(KMMainWidget *mainWidget);
 
