@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,10 +8,11 @@
 #ifndef REMOVEDUPLICATEMESSAGEINFOLDERANDSUBFOLDERJOB_H
 #define REMOVEDUPLICATEMESSAGEINFOLDERANDSUBFOLDERJOB_H
 
-#include <QObject>
 #include <AkonadiCore/Collection>
+#include <QObject>
 class KJob;
-namespace KPIM {
+namespace KPIM
+{
 class ProgressItem;
 }
 class RemoveDuplicateMessageInFolderAndSubFolderJob : public QObject
@@ -19,7 +20,7 @@ class RemoveDuplicateMessageInFolderAndSubFolderJob : public QObject
     Q_OBJECT
 public:
     explicit RemoveDuplicateMessageInFolderAndSubFolderJob(QObject *parent = nullptr, QWidget *parentWidget = nullptr);
-    ~RemoveDuplicateMessageInFolderAndSubFolderJob();
+    ~RemoveDuplicateMessageInFolderAndSubFolderJob() override;
 
     void start();
 
