@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -14,7 +14,7 @@ class SaveAsFileJob : public QObject
     Q_OBJECT
 public:
     explicit SaveAsFileJob(QObject *parent = nullptr);
-    ~SaveAsFileJob();
+    ~SaveAsFileJob() override;
     void start();
 
     void setHtmlMode(bool htmlMode);
