@@ -1,16 +1,16 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "savedraftjob.h"
+#include "kmail_debug.h"
+#include <Akonadi/KMime/MessageFlags>
 #include <Akonadi/KMime/MessageStatus>
 #include <AkonadiCore/Item>
 #include <AkonadiCore/ItemCreateJob>
-#include "kmail_debug.h"
-#include <Akonadi/KMime/MessageFlags>
 
 SaveDraftJob::SaveDraftJob(const KMime::Message::Ptr &msg, const Akonadi::Collection &col, QObject *parent)
     : KJob(parent)
@@ -19,8 +19,7 @@ SaveDraftJob::SaveDraftJob(const KMime::Message::Ptr &msg, const Akonadi::Collec
 {
 }
 
-SaveDraftJob::~SaveDraftJob()
-= default;
+SaveDraftJob::~SaveDraftJob() = default;
 
 void SaveDraftJob::start()
 {
@@ -30,7 +29,7 @@ void SaveDraftJob::start()
     item.setFlag(Akonadi::MessageFlags::Seen);
     Akonadi::MessageFlags::copyMessageFlags(*mMsg, item);
 
-    auto *createJob = new Akonadi::ItemCreateJob(item, mCollection);
+    auto createJob = new Akonadi::ItemCreateJob(item, mCollection);
     connect(createJob, &Akonadi::ItemCreateJob::result, this, &SaveDraftJob::slotStoreDone);
 }
 
