@@ -5,68 +5,79 @@
 
 #include <MailCommon/MailInterfaces>
 
+#include <QDBusObjectPath>
 #include <QList>
 #include <QObject>
 #include <QPointer>
-#include <QDBusObjectPath>
 
 #include <QUrl>
 
 #include "kmail_export.h"
 #include "settings/kmailsettings.h"
 #include <AkonadiCore/servermanager.h>
-#include <MessageViewer/Viewer>
 #include <Libkdepim/ProgressManager>
+#include <MessageViewer/Viewer>
 
 #define kmkernel KMKernel::self()
 #define kmconfig KMKernel::config()
 
 class QAbstractItemModel;
-namespace Akonadi {
+namespace Akonadi
+{
 class Collection;
 class ChangeRecorder;
 class EntityTreeModel;
 class EntityMimeTypeFilterModel;
 }
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 class IndexedItems;
 }
 }
 }
 
-namespace KIO {
+namespace KIO
+{
 class Job;
 }
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class MessageSender;
 }
-namespace PimCommon {
+namespace PimCommon
+{
 class AutoCorrection;
 }
 
 /** The KMail namespace contains classes used for KMail.
-* This is to keep them out of the way from all the other
-* un-namespaced classes in libs and the rest of PIM.
-*/
-namespace KMail {
+ * This is to keep them out of the way from all the other
+ * un-namespaced classes in libs and the rest of PIM.
+ */
+namespace KMail
+{
 class MailServiceImpl;
 class UndoStack;
 class UnityServiceManager;
 }
-namespace MessageComposer {
+namespace MessageComposer
+{
 class AkonadiSender;
 }
 
-namespace KIdentityManagement {
+namespace KIdentityManagement
+{
 class Identity;
 class IdentityManager;
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 class Kernel;
 class FolderSettings;
 class FolderCollectionMonitor;
@@ -77,7 +88,8 @@ class MailCommonSettings;
 
 #ifdef WITH_KUSERFEEDBACK
 class KMailUserFeedbackProvider;
-namespace KUserFeedback {
+namespace KUserFeedback
+{
 class Provider;
 }
 #endif
@@ -119,36 +131,36 @@ public:
     ~KMKernel() override;
 
     /**
-    * Start of D-Bus callable stuff. The D-Bus methods need to be public slots,
-    * otherwise they can't be accessed.
-    */
+     * Start of D-Bus callable stuff. The D-Bus methods need to be public slots,
+     * otherwise they can't be accessed.
+     */
 public Q_SLOTS:
 
     Q_SCRIPTABLE void checkMail();
     Q_SCRIPTABLE void openReader();
 
     /**
-    * Pauses all background jobs and does not
-    * allow new background jobs to be started.
-    */
+     * Pauses all background jobs and does not
+     * allow new background jobs to be started.
+     */
     Q_SCRIPTABLE void pauseBackgroundJobs();
 
     /**
-    * Resumes all background jobs and allows
-    * new jobs to be started.
-    */
+     * Resumes all background jobs and allows
+     * new jobs to be started.
+     */
     Q_SCRIPTABLE void resumeBackgroundJobs();
 
     /**
-    * Stops all network related jobs and enter offline mode
-    * New network jobs cannot be started.
-    */
+     * Stops all network related jobs and enter offline mode
+     * New network jobs cannot be started.
+     */
     Q_SCRIPTABLE void stopNetworkJobs();
 
     /**
-    * Resumes all network related jobs and enter online mode
-    * New network jobs can be started.
-    */
+     * Resumes all network related jobs and enter online mode
+     * New network jobs can be started.
+     */
     Q_SCRIPTABLE void resumeNetworkJobs();
 
     Q_SCRIPTABLE QStringList accounts() const;
@@ -156,10 +168,10 @@ public Q_SLOTS:
     Q_SCRIPTABLE void makeResourceOnline(MessageViewer::Viewer::ResourceOnlineMode mode);
 
     /**
-    * Checks the account with the specified name for new mail.
-    * If the account name is empty, all accounts not excluded from manual
-    * mail check will be checked.
-    */
+     * Checks the account with the specified name for new mail.
+     * If the account name is empty, all accounts not excluded from manual
+     * mail check will be checked.
+     */
     Q_SCRIPTABLE void checkAccount(const QString &account);
 
     Q_SCRIPTABLE bool selectFolder(const QString &folder);
@@ -169,103 +181,141 @@ public Q_SLOTS:
     Q_SCRIPTABLE bool handleCommandLine(bool noArgsOpensReader, const QStringList &args, const QString &workingDir);
 
     /**
-    * Opens a composer window and prefills it with different
-    * message parts.
-    *
-    *
-    * @param to A comma separated list of To addresses.
-    * @param cc A comma separated list of CC addresses.
-    * @param bcc A comma separated list of BCC addresses.
-    * @param subject The message subject.
-    * @param body The message body.
-    * @param hidden Whether the composer window shall initially be hidden.
-    * @param messageFile A message file that will be used as message body.
-    * @param attachmentPaths A list of files that will be attached to the message.
-    * @param customHeaders A list of custom headers.
-    * @param replyTo A list of reply-to headers.
-    * @param inReplyTo A list of in-reply-to headers.
-    * @param identity The mail identity.
-    */
-    Q_SCRIPTABLE void openComposer(const QString &to, const QString &cc, const QString &bcc, const QString &subject, const QString &body, bool hidden, const QString &messageFile, const QStringList &attachmentPaths, const QStringList &customHeaders,
-                                   const QString &replyTo = QString(), const QString &inReplyTo = QString(), const QString &identity = QString());
+     * Opens a composer window and prefills it with different
+     * message parts.
+     *
+     *
+     * @param to A comma separated list of To addresses.
+     * @param cc A comma separated list of CC addresses.
+     * @param bcc A comma separated list of BCC addresses.
+     * @param subject The message subject.
+     * @param body The message body.
+     * @param hidden Whether the composer window shall initially be hidden.
+     * @param messageFile A message file that will be used as message body.
+     * @param attachmentPaths A list of files that will be attached to the message.
+     * @param customHeaders A list of custom headers.
+     * @param replyTo A list of reply-to headers.
+     * @param inReplyTo A list of in-reply-to headers.
+     * @param identity The mail identity.
+     */
+    Q_SCRIPTABLE void openComposer(const QString &to,
+                                   const QString &cc,
+                                   const QString &bcc,
+                                   const QString &subject,
+                                   const QString &body,
+                                   bool hidden,
+                                   const QString &messageFile,
+                                   const QStringList &attachmentPaths,
+                                   const QStringList &customHeaders,
+                                   const QString &replyTo = QString(),
+                                   const QString &inReplyTo = QString(),
+                                   const QString &identity = QString());
 
     /**
-    * Opens a composer window and prefills it with different
-    * message parts.
-    *
-    * @param to A comma separated list of To addresses.
-    * @param cc A comma separated list of CC addresses.
-    * @param bcc A comma separated list of BCC addresses.
-    * @param subject The message subject.
-    * @param body The message body.
-    * @param hidden Whether the composer window shall initially be hidden.
-    * @param attachName The name of the attachment.
-    * @param attachCte The content transfer encoding of the attachment.
-    * @param attachData The raw data of the attachment.
-    * @param attachType The mime type of the attachment.
-    * @param attachSubType The sub mime type of the attachment.
-    * @param attachParamAttr The parameter attribute of the attachment.
-    * @param attachParamValue The parameter value of the attachment.
-    * @param attachContDisp The content display type of the attachment.
-    * @param attachCharset The charset of the attachment.
-    * @param identity The identity identifier which will be used as sender identity.
-    */
-    Q_SCRIPTABLE void openComposer(const QString &to, const QString &cc, const QString &bcc, const QString &subject, const QString &body, bool hidden, const QString &attachName, const QByteArray &attachCte, const QByteArray &attachData, const QByteArray &attachType, const QByteArray &attachSubType,
-                                   const QByteArray &attachParamAttr, const QString &attachParamValue, const QByteArray &attachContDisp, const QByteArray &attachCharset, unsigned int identity);
+     * Opens a composer window and prefills it with different
+     * message parts.
+     *
+     * @param to A comma separated list of To addresses.
+     * @param cc A comma separated list of CC addresses.
+     * @param bcc A comma separated list of BCC addresses.
+     * @param subject The message subject.
+     * @param body The message body.
+     * @param hidden Whether the composer window shall initially be hidden.
+     * @param attachName The name of the attachment.
+     * @param attachCte The content transfer encoding of the attachment.
+     * @param attachData The raw data of the attachment.
+     * @param attachType The mime type of the attachment.
+     * @param attachSubType The sub mime type of the attachment.
+     * @param attachParamAttr The parameter attribute of the attachment.
+     * @param attachParamValue The parameter value of the attachment.
+     * @param attachContDisp The content display type of the attachment.
+     * @param attachCharset The charset of the attachment.
+     * @param identity The identity identifier which will be used as sender identity.
+     */
+    Q_SCRIPTABLE void openComposer(const QString &to,
+                                   const QString &cc,
+                                   const QString &bcc,
+                                   const QString &subject,
+                                   const QString &body,
+                                   bool hidden,
+                                   const QString &attachName,
+                                   const QByteArray &attachCte,
+                                   const QByteArray &attachData,
+                                   const QByteArray &attachType,
+                                   const QByteArray &attachSubType,
+                                   const QByteArray &attachParamAttr,
+                                   const QString &attachParamValue,
+                                   const QByteArray &attachContDisp,
+                                   const QByteArray &attachCharset,
+                                   unsigned int identity);
 
     /**
-    * Opens a composer window and prefills it with different
-    * message parts.
-    * @since 5.0
-    *
-    * @param to A comma separated list of To addresses.
-    * @param cc A comma separated list of CC addresses.
-    * @param bcc A comma separated list of BCC addresses.
-    * @param subject The message subject.
-    * @param body The message body.
-    * @param attachName The name of the attachment.
-    * @param attachCte The content transfer encoding of the attachment.
-    * @param attachData The raw data of the attachment.
-    * @param attachType The mime type of the attachment.
-    * @param attachSubType The sub mime type of the attachment.
-    * @param attachParamAttr The parameter attribute of the attachment.
-    * @param attachParamValue The parameter value of the attachment.
-    * @param attachContDisp The content display type of the attachment.
-    * @param attachCharset The charset of the attachment.
-    * @param identity The identity identifier which will be used as sender identity.
-    */
-    Q_SCRIPTABLE void openComposer(const QString &to, const QString &cc, const QString &bcc, const QString &subject, const QString &body, const QString &attachName, const QByteArray &attachCte, const QByteArray &attachData, const QByteArray &attachType, const QByteArray &attachSubType,
-                                   const QByteArray &attachParamAttr, const QString &attachParamValue, const QByteArray &attachContDisp, const QByteArray &attachCharset, unsigned int identity);
+     * Opens a composer window and prefills it with different
+     * message parts.
+     * @since 5.0
+     *
+     * @param to A comma separated list of To addresses.
+     * @param cc A comma separated list of CC addresses.
+     * @param bcc A comma separated list of BCC addresses.
+     * @param subject The message subject.
+     * @param body The message body.
+     * @param attachName The name of the attachment.
+     * @param attachCte The content transfer encoding of the attachment.
+     * @param attachData The raw data of the attachment.
+     * @param attachType The mime type of the attachment.
+     * @param attachSubType The sub mime type of the attachment.
+     * @param attachParamAttr The parameter attribute of the attachment.
+     * @param attachParamValue The parameter value of the attachment.
+     * @param attachContDisp The content display type of the attachment.
+     * @param attachCharset The charset of the attachment.
+     * @param identity The identity identifier which will be used as sender identity.
+     */
+    Q_SCRIPTABLE void openComposer(const QString &to,
+                                   const QString &cc,
+                                   const QString &bcc,
+                                   const QString &subject,
+                                   const QString &body,
+                                   const QString &attachName,
+                                   const QByteArray &attachCte,
+                                   const QByteArray &attachData,
+                                   const QByteArray &attachType,
+                                   const QByteArray &attachSubType,
+                                   const QByteArray &attachParamAttr,
+                                   const QString &attachParamValue,
+                                   const QByteArray &attachContDisp,
+                                   const QByteArray &attachCharset,
+                                   unsigned int identity);
 
     /**
-    * Opens a composer window and prefills it with different
-    * message parts.
-    *
-    *
-    * @param to A comma separated list of To addresses.
-    * @param cc A comma separated list of CC addresses.
-    * @param bcc A comma separated list of BCC addresses.
-    * @param subject The message subject.
-    * @param body The message body.
-    * @param hidden Whether the composer window shall initially be hidden.
-    */
+     * Opens a composer window and prefills it with different
+     * message parts.
+     *
+     *
+     * @param to A comma separated list of To addresses.
+     * @param cc A comma separated list of CC addresses.
+     * @param bcc A comma separated list of BCC addresses.
+     * @param subject The message subject.
+     * @param body The message body.
+     * @param hidden Whether the composer window shall initially be hidden.
+     */
     Q_SCRIPTABLE void openComposer(const QString &to, const QString &cc, const QString &bcc, const QString &subject, const QString &body, bool hidden);
 
     /**
-    * Opens a composer window and prefills it with different
-    * message parts.
-    *
-    * @returns The DBus object path for the composer.
-    *
-    * @param to A comma separated list of To addresses.
-    * @param cc A comma separated list of CC addresses.
-    * @param bcc A comma separated list of BCC addresses.
-    * @param hidden Whether the composer window shall initially be hidden.
-    * @param useFolderId The id of the folder whose associated identity will be used.
-    * @param messageFile A message file that will be used as message body.
-    * @param attachURL The URL to the file that will be attached to the message.
-    */
-    Q_SCRIPTABLE void newMessage(const QString &to, const QString &cc, const QString &bcc, bool hidden, bool useFolderId, const QString &messageFile, const QString &attachURL);
+     * Opens a composer window and prefills it with different
+     * message parts.
+     *
+     * @returns The DBus object path for the composer.
+     *
+     * @param to A comma separated list of To addresses.
+     * @param cc A comma separated list of CC addresses.
+     * @param bcc A comma separated list of BCC addresses.
+     * @param hidden Whether the composer window shall initially be hidden.
+     * @param useFolderId The id of the folder whose associated identity will be used.
+     * @param messageFile A message file that will be used as message body.
+     * @param attachURL The URL to the file that will be attached to the message.
+     */
+    Q_SCRIPTABLE void
+    newMessage(const QString &to, const QString &cc, const QString &bcc, bool hidden, bool useFolderId, const QString &messageFile, const QString &attachURL);
 
     Q_SCRIPTABLE bool showMail(qint64 serialNumber);
 
@@ -278,23 +328,23 @@ public Q_SLOTS:
     Q_SCRIPTABLE void reloadFolderArchiveConfig();
 
     /**
-    * End of D-Bus callable stuff
-    */
+     * End of D-Bus callable stuff
+     */
 
 public:
     void checkMailOnStartup();
 
     /** A static helper function that asks the user
-    * if they want to go online.
-    * @return true if the user wants to go online
-    * @return false if the user wants to stay offline
-    */
+     * if they want to go online.
+     * @return true if the user wants to go online
+     * @return false if the user wants to stay offline
+     */
     static bool askToGoOnline();
 
     /** Checks if the current network state is online or offline
-    * @return true if the network state is offline
-    * @return false if the network state is online
-    */
+     * @return true if the network state is offline
+     * @return false if the network state is online
+     */
     static bool isOffline();
 
     /** normal control stuff */
@@ -310,14 +360,14 @@ public:
     Akonadi::ChangeRecorder *folderCollectionMonitor() const override;
 
     /**
-    * Returns the main model, which contains all folders and the items of recently opened folders.
-    */
+     * Returns the main model, which contains all folders and the items of recently opened folders.
+     */
     Akonadi::EntityTreeModel *entityTreeModel() const;
 
     /**
-    * Returns a model of all folders in KMail. This is basically the same as entityTreeModel(),
-    * but with items filtered out, the model contains only collections.
-    */
+     * Returns a model of all folders in KMail. This is basically the same as entityTreeModel(),
+     * but with items filtered out, the model contains only collections.
+     */
     Akonadi::EntityMimeTypeFilterModel *collectionModel() const override;
 
     void recoverDeadLetters();
@@ -327,10 +377,22 @@ public:
     bool doSessionManagement();
     bool firstInstance() const;
     void setFirstInstance(bool value);
-    void action(bool mailto, bool check, bool startInTray, const QString &to, const QString &cc, const QString &bcc, const QString &subj, const QString &body, const QUrl &messageFile, const QList<QUrl> &attach, const QStringList &customHeaders, const QString &replyTo, const QString &inReplyTo,
+    void action(bool mailto,
+                bool check,
+                bool startInTray,
+                const QString &to,
+                const QString &cc,
+                const QString &bcc,
+                const QString &subj,
+                const QString &body,
+                const QUrl &messageFile,
+                const QList<QUrl> &attach,
+                const QStringList &customHeaders,
+                const QString &replyTo,
+                const QString &inReplyTo,
                 const QString &identity);
 
-    //sets online status for akonadi accounts. true for online, false for offline
+    // sets online status for akonadi accounts. true for online, false for offline
     void setAccountStatus(bool);
 
     const QString xmlGuiInstanceName() const;
@@ -355,9 +417,9 @@ public:
     void setShuttingDown(bool flag);
 
     /** Returns true if we have a system tray applet. This is needed in order
-    *  to know whether the application should be allowed to exit in case the
-    *  last visible composer or separate message window is closed.
-    */
+     *  to know whether the application should be allowed to exit in case the
+     *  last visible composer or separate message window is closed.
+     */
     bool haveSystemTrayApplet() const;
 
     QTextCodec *networkCodec() const;
@@ -369,9 +431,9 @@ public:
     KMMainWidget *getKMMainWidget();
 
     /**
-    * Returns a list of all currently loaded folders. Since folders are loaded async, this
-    * is empty at startup.
-    */
+     * Returns a list of all currently loaded folders. Since folders are loaded async, this
+     * is empty at startup.
+     */
     Akonadi::Collection::List allFolders() const;
 
     /**
@@ -386,7 +448,7 @@ public:
 
     void stopAgentInstance();
 
-    //ISettings
+    // ISettings
     bool showPopupAfterDnD() override;
 
     bool excludeImportantMailFromExpiry() override;
@@ -442,8 +504,8 @@ public Q_SLOTS:
     void slotRequestConfigSync();
 
     /**
-    * Sync the config immediatley
-    */
+     * Sync the config immediatley
+     */
     void slotSyncConfig();
 
     void slotShowConfigurationDialog();
@@ -479,6 +541,7 @@ private Q_SLOTS:
     void slotCollectionChanged(const Akonadi::Collection &, const QSet<QByteArray> &set);
 
     void slotCheckAccount(Akonadi::ServerManager::State state);
+
 private:
     void viewMessage(const QUrl &url);
     Akonadi::Collection currentCollection();
@@ -486,9 +549,24 @@ private:
     /*
      * Fills a composer cWin
      *
-    */
-    void fillComposer(bool hidden, const QString &to, const QString &cc, const QString &bcc, const QString &subject, const QString &body, const QString &attachName, const QByteArray &attachCte, const QByteArray &attachData, const QByteArray &attachType, const QByteArray &attachSubType,
-                      const QByteArray &attachParamAttr, const QString &attachParamValue, const QByteArray &attachContDisp, const QByteArray &attachCharset, unsigned int identity, bool forceShowWindow);
+     */
+    void fillComposer(bool hidden,
+                      const QString &to,
+                      const QString &cc,
+                      const QString &bcc,
+                      const QString &subject,
+                      const QString &body,
+                      const QString &attachName,
+                      const QByteArray &attachCte,
+                      const QByteArray &attachData,
+                      const QByteArray &attachType,
+                      const QByteArray &attachSubType,
+                      const QByteArray &attachParamAttr,
+                      const QString &attachParamValue,
+                      const QByteArray &attachContDisp,
+                      const QByteArray &attachCharset,
+                      unsigned int identity,
+                      bool forceShowWindow);
 
     void verifyAccount();
     void resourceGoOnLine();
