@@ -6,52 +6,52 @@
 
 #include "messageactions.h"
 
-#include "settings/kmailsettings.h"
-#include "kmreaderwin.h"
-#include "kmkernel.h"
-#include <MailCommon/MailKernel>
-#include "kmmainwidget.h"
-#include "util.h"
 #include "kmcommands.h"
+#include "kmkernel.h"
+#include "kmmainwidget.h"
+#include "kmreaderwin.h"
+#include "settings/kmailsettings.h"
+#include "util.h"
+#include <MailCommon/MailKernel>
 #include <TemplateParser/CustomTemplatesMenu>
 
-#include <PimCommonAkonadi/AnnotationDialog>
-#include <MessageCore/MessageCoreSettings>
 #include <MessageCore/MailingList>
+#include <MessageCore/MessageCoreSettings>
 #include <MessageCore/StringUtil>
-#include <MessageViewer/MessageViewerSettings>
 #include <MessageViewer/HeaderStylePlugin>
+#include <MessageViewer/MessageViewerSettings>
+#include <PimCommonAkonadi/AnnotationDialog>
 
-#include <AkonadiCore/itemfetchjob.h>
 #include <Akonadi/KMime/MessageParts>
 #include <AkonadiCore/ChangeRecorder>
-#include <QAction>
+#include <AkonadiCore/itemfetchjob.h>
 #include <AkonadiSearch/Debug/akonadisearchdebugdialog.h>
 #include <KIO/KUriFilterSearchProviderActions>
+#include <QAction>
 
-#include <MessageComposer/FollowUpReminderSelectDateDialog>
 #include "job/createfollowupreminderonexistingmessagejob.h"
+#include <MessageComposer/FollowUpReminderSelectDateDialog>
 
-#include <AkonadiCore/ItemFetchJob>
-#include <KActionMenu>
-#include <KActionCollection>
 #include "kmail_debug.h"
-#include <KLocalizedString>
-#include <KXMLGUIClient>
-#include <KIO/OpenUrlJob>
+#include <AkonadiCore/ItemFetchJob>
+#include <KActionCollection>
+#include <KActionMenu>
 #include <KIO/JobUiDelegate>
-#include <QMenu>
-#include <KUriFilter>
+#include <KIO/OpenUrlJob>
+#include <KLocalizedString>
 #include <KStringHandler>
-#include <QIcon>
+#include <KUriFilter>
+#include <KXMLGUIClient>
 #include <QFileDialog>
+#include <QIcon>
+#include <QMenu>
 
-#include <QVariant>
-#include <QWidget>
 #include <AkonadiCore/collection.h>
 #include <AkonadiCore/entityannotationsattribute.h>
 #include <MailCommon/MailUtil>
 #include <MessageViewer/MessageViewerUtil>
+#include <QVariant>
+#include <QWidget>
 
 using namespace KMail;
 
@@ -72,7 +72,7 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
 
     mReplyAuthorAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18n("Reply to A&uthor..."), this);
     ac->addAction(QStringLiteral("reply_author"), mReplyAuthorAction);
-    ac->setDefaultShortcut(mReplyAuthorAction, Qt::SHIFT + Qt::Key_A);
+    ac->setDefaultShortcut(mReplyAuthorAction, Qt::SHIFT | Qt::Key_A);
     connect(mReplyAuthorAction, &QAction::triggered, this, &MessageActions::slotReplyAuthorToMsg);
     mReplyActionMenu->addAction(mReplyAuthorAction);
 
@@ -91,7 +91,7 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
 
     mNoQuoteReplyAction = new QAction(i18n("Reply Without &Quote..."), this);
     ac->addAction(QStringLiteral("noquotereply"), mNoQuoteReplyAction);
-    ac->setDefaultShortcut(mNoQuoteReplyAction, Qt::SHIFT + Qt::Key_R);
+    ac->setDefaultShortcut(mNoQuoteReplyAction, Qt::SHIFT | Qt::Key_R);
     connect(mNoQuoteReplyAction, &QAction::triggered, this, &MessageActions::slotNoQuoteReplyToMsg);
 
     mListFilterAction = new QAction(i18n("Filter on Mailing-&List..."), this);
@@ -116,18 +116,13 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
     mForwardActionMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("Message->", "&Forward"), this);
     ac->addAction(QStringLiteral("message_forward"), mForwardActionMenu);
 
-    mForwardAttachedAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")),
-                                         i18nc("@action:inmenu Message->Forward->",
-                                               "As &Attachment..."),
-                                         this);
+    mForwardAttachedAction =
+        new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("@action:inmenu Message->Forward->", "As &Attachment..."), this);
     connect(mForwardAttachedAction, SIGNAL(triggered(bool)), parent, SLOT(slotForwardAttachedMessage()));
 
     ac->addAction(QStringLiteral("message_forward_as_attachment"), mForwardAttachedAction);
 
-    mForwardInlineAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")),
-                                       i18nc("@action:inmenu Message->Forward->",
-                                             "&Inline..."),
-                                       this);
+    mForwardInlineAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("@action:inmenu Message->Forward->", "&Inline..."), this);
     connect(mForwardInlineAction, SIGNAL(triggered(bool)), parent, SLOT(slotForwardInlineMsg()));
 
     ac->addAction(QStringLiteral("message_forward_inline"), mForwardInlineAction);
@@ -162,7 +157,7 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
     replyMenu()->addAction(mCustomTemplatesMenu->replyActionMenu());
     replyMenu()->addAction(mCustomTemplatesMenu->replyAllActionMenu());
 
-    //Don't translate it. Shown only when we set env variable AKONADI_SEARCH_DEBUG
+    // Don't translate it. Shown only when we set env variable AKONADI_SEARCH_DEBUG
     mDebugAkonadiSearchAction = new QAction(QStringLiteral("Debug Akonadi Search..."), this);
     connect(mDebugAkonadiSearchAction, &QAction::triggered, this, &MessageActions::slotDebugAkonadiSearch);
 
@@ -177,7 +172,7 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
     mNewMessageFromTemplateAction = new QAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New Message From &Template"), this);
     ac->addAction(QStringLiteral("use_template"), mNewMessageFromTemplateAction);
     connect(mNewMessageFromTemplateAction, &QAction::triggered, this, &MessageActions::slotUseTemplate);
-    ac->setDefaultShortcut(mNewMessageFromTemplateAction, QKeySequence(Qt::SHIFT + Qt::Key_N));
+    ac->setDefaultShortcut(mNewMessageFromTemplateAction, QKeySequence(Qt::SHIFT | Qt::Key_N));
 
     mExportToPdfAction = new QAction(QIcon::fromTheme(QStringLiteral("application-pdf")), i18n("Export to PDF..."), this);
     ac->addAction(QStringLiteral("file_export_pdf"), mExportToPdfAction);
@@ -314,9 +309,9 @@ void MessageActions::slotItemRemoved(const Akonadi::Item &item)
     }
 }
 
-void MessageActions::slotItemModified(const Akonadi::Item &item, const QSet< QByteArray > &partIdentifiers)
+void MessageActions::slotItemModified(const Akonadi::Item &item, const QSet<QByteArray> &partIdentifiers)
 {
-    Q_UNUSED(partIdentifiers);
+    Q_UNUSED(partIdentifiers)
     if (item == mCurrentItem) {
         mCurrentItem = item;
         const int numberOfVisibleItems = mVisibleItems.count();
@@ -372,7 +367,7 @@ void MessageActions::updateActions()
         if (mCurrentItem.loadedPayloadParts().contains("RFC822")) {
             updateMailingListActions(mCurrentItem);
         } else {
-            auto *job = new Akonadi::ItemFetchJob(mCurrentItem);
+            auto job = new Akonadi::ItemFetchJob(mCurrentItem);
             job->fetchScope().fetchAllAttributes();
             job->fetchScope().fetchFullPayload(true);
             job->fetchScope().fetchPayloadPart(Akonadi::MessagePart::Header);
@@ -389,7 +384,7 @@ void MessageActions::slotUpdateActionsFetchDone(KJob *job)
         return;
     }
 
-    auto *fetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
+    auto fetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
     if (fetchJob->items().isEmpty()) {
         return;
     }
@@ -430,7 +425,7 @@ void MessageActions::updateMailingListActions(const Akonadi::Item &messageItem)
                 listId.truncate(start - 1);
             } else if (start == 0) {
                 const int end = listId.lastIndexOf(QLatin1Char('>'));
-                if (end < 1) {   // shouldn't happen but account for it anyway
+                if (end < 1) { // shouldn't happen but account for it anyway
                     listId.remove(0, 1);
                 } else {
                     listId = listId.mid(1, end - 1);
@@ -482,7 +477,7 @@ void MessageActions::replyCommand(MessageComposer::ReplyStrategy strategy)
     }
 
     const QString text = mMessageView ? mMessageView->copyText() : QString();
-    KMReplyCommand *command = new KMReplyCommand(mParent, mCurrentItem, strategy, text);
+    auto command = new KMReplyCommand(mParent, mCurrentItem, strategy, text);
     command->setReplyAsHtml(mMessageView ? mMessageView->viewer()->htmlMail() : false);
     connect(command, &KMCommand::completed, this, &MessageActions::replyActionFinished);
     command->start();
@@ -503,16 +498,14 @@ void MessageActions::setupForwardActions(KActionCollection *ac)
         mForwardActionMenu->insertAction(mRedirectAction, mForwardInlineAction);
         mForwardActionMenu->insertAction(mRedirectAction, mForwardAttachedAction);
         ac->setDefaultShortcut(mForwardInlineAction, QKeySequence(Qt::Key_F));
-        ac->setDefaultShortcut(mForwardAttachedAction, QKeySequence(Qt::SHIFT + Qt::Key_F));
-        QObject::connect(mForwardActionMenu, SIGNAL(triggered(bool)),
-                         mParent, SLOT(slotForwardInlineMsg()));
+        ac->setDefaultShortcut(mForwardAttachedAction, QKeySequence(Qt::SHIFT | Qt::Key_F));
+        QObject::connect(mForwardActionMenu, SIGNAL(triggered(bool)), mParent, SLOT(slotForwardInlineMsg()));
     } else {
         mForwardActionMenu->insertAction(mRedirectAction, mForwardAttachedAction);
         mForwardActionMenu->insertAction(mRedirectAction, mForwardInlineAction);
         ac->setDefaultShortcut(mForwardInlineAction, QKeySequence(Qt::Key_F));
-        ac->setDefaultShortcut(mForwardAttachedAction, QKeySequence(Qt::SHIFT + Qt::Key_F));
-        QObject::connect(mForwardActionMenu, SIGNAL(triggered(bool)),
-                         mParent, SLOT(slotForwardAttachedMessage()));
+        ac->setDefaultShortcut(mForwardAttachedAction, QKeySequence(Qt::SHIFT | Qt::Key_F));
+        QObject::connect(mForwardActionMenu, SIGNAL(triggered(bool)), mParent, SLOT(slotForwardAttachedMessage()));
     }
 }
 
@@ -556,7 +549,7 @@ void MessageActions::slotNoQuoteReplyToMsg()
     if (!mCurrentItem.hasPayload<KMime::Message::Ptr>()) {
         return;
     }
-    KMReplyCommand *command = new KMReplyCommand(mParent, mCurrentItem, MessageComposer::ReplySmart, QString(), true);
+    auto command = new KMReplyCommand(mParent, mCurrentItem, MessageComposer::ReplySmart, QString(), true);
     command->setReplyAsHtml(mMessageView ? mMessageView->viewer()->htmlMail() : false);
 
     command->start();
@@ -566,7 +559,7 @@ void MessageActions::slotRunUrl(QAction *urlAction)
 {
     const QVariant q = urlAction->data();
     if (q.type() == QVariant::Url) {
-        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(q.toUrl());
+        auto job = new KIO::OpenUrlJob(q.toUrl());
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mParent));
         job->start();
     }
@@ -602,11 +595,12 @@ void MessageActions::printMessage(bool preview)
             commandInfo.mPrintPreview = preview;
             commandInfo.mUseFixedFont = useFixedFont;
             commandInfo.mOverrideFont = overrideEncoding;
-            commandInfo.mShowSignatureDetails = mMessageView->viewer()->showSignatureDetails() || MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetails();
-            commandInfo.mShowEncryptionDetails = mMessageView->viewer()->showEncryptionDetails() || MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetails();
+            commandInfo.mShowSignatureDetails =
+                mMessageView->viewer()->showSignatureDetails() || MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetails();
+            commandInfo.mShowEncryptionDetails =
+                mMessageView->viewer()->showEncryptionDetails() || MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetails();
 
-            auto *command
-                = new KMPrintCommand(mParent, commandInfo);
+            auto command = new KMPrintCommand(mParent, commandInfo);
             command->start();
         }
     } else {
@@ -649,13 +643,17 @@ void MessageActions::addMailingListAction(const QString &item, const QUrl &url)
     QString prettyUrl = url.toDisplayString();
     if (protocol == QLatin1String("mailto")) {
         protocol = i18n("email");
-        prettyUrl.remove(0, 7);   // length( "mailto:" )
+        prettyUrl.remove(0, 7); // length( "mailto:" )
     } else if (protocol.startsWith(QLatin1String("http"))) {
         protocol = i18n("web");
     }
     // item is a mailing list url description passed from the updateActions method above.
-    QAction *act
-        = new QAction(i18nc("%1 is a 'Contact Owner' or similar action. %2 is a protocol normally web or email though could be irc/ftp or other url variant", "%1 (%2)", item, protocol), this);
+    auto *act =
+        new QAction(i18nc("%1 is a 'Contact Owner' or similar action. %2 is a protocol normally web or email though could be irc/ftp or other url variant",
+                          "%1 (%2)",
+                          item,
+                          protocol),
+                    this);
     mMailListActionList.append(act);
     const QVariant v(url);
     act->setData(v);
@@ -671,10 +669,7 @@ void MessageActions::editCurrentMessage()
         qCDebug(KMAIL_LOG) << " mCurrentItem.parentCollection()" << mCurrentItem.parentCollection();
         // edit, unlike send again, removes the message from the folder
         // we only want that for templates and drafts folders
-        if (col.isValid()
-            && (CommonKernel->folderIsDraftOrOutbox(col)
-                || CommonKernel->folderIsTemplates(col))
-            ) {
+        if (col.isValid() && (CommonKernel->folderIsDraftOrOutbox(col) || CommonKernel->folderIsTemplates(col))) {
             command = new KMEditItemCommand(mParent, mCurrentItem, true);
         } else {
             command = new KMEditItemCommand(mParent, mCurrentItem, false);
@@ -754,7 +749,7 @@ void MessageActions::slotAddFollowupReminder()
     QPointer<MessageComposer::FollowUpReminderSelectDateDialog> dlg = new MessageComposer::FollowUpReminderSelectDateDialog(mParent);
     if (dlg->exec()) {
         const QDate date = dlg->selectedDate();
-        auto *job = new CreateFollowupReminderOnExistingMessageJob(this);
+        auto job = new CreateFollowupReminderOnExistingMessageJob(this);
         job->setDate(date);
         job->setCollection(dlg->collection());
         job->setMessageItem(mCurrentItem);
@@ -766,9 +761,7 @@ void MessageActions::slotAddFollowupReminder()
 void MessageActions::slotExportToPdf()
 {
     QString fileName = MessageViewer::Util::generateFileNameForExtension(mCurrentItem, QStringLiteral(".pdf"));
-    fileName = QFileDialog::getSaveFileName(mParent, i18n("Export to PDF"),
-                                            QDir::homePath() + QLatin1Char('/') + fileName,
-                                            i18n("PDF document (*.pdf)"));
+    fileName = QFileDialog::getSaveFileName(mParent, i18n("Export to PDF"), QDir::homePath() + QLatin1Char('/') + fileName, i18n("PDF document (*.pdf)"));
     if (!fileName.isEmpty()) {
         mMessageView->viewer()->exportToPdf(fileName);
     }
