@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -9,13 +9,14 @@
 
 #include <MailCommon/SearchPatternEdit>
 
-namespace KMail {
+namespace KMail
+{
 class KMailSearchPatternEdit : public MailCommon::SearchPatternEdit
 {
     Q_OBJECT
 public:
     explicit KMailSearchPatternEdit(QWidget *parent = nullptr);
-    ~KMailSearchPatternEdit();
+    ~KMailSearchPatternEdit() override;
 };
 }
 #endif // KMailSearchPatternEdit_H
