@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,13 +9,14 @@
 
 #include <KMessageWidget>
 
-namespace KMail {
+namespace KMail
+{
 class SearchPatternWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit SearchPatternWarning(QWidget *parent = nullptr);
-    ~SearchPatternWarning();
+    ~SearchPatternWarning() override;
 
     void showWarningPattern(const QStringList &lstError);
     void hideWarningPattern();
