@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class UndoSendManager : public QObject
     Q_OBJECT
 public:
     explicit UndoSendManager(QObject *parent = nullptr);
-    ~UndoSendManager();
+    ~UndoSendManager() override;
     static UndoSendManager *self();
 
     void addItem(qint64 index, const QString &subject, int delay);
