@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef KMAILUSERFEEDBACKPROVIDER_H
 #define KMAILUSERFEEDBACKPROVIDER_H
 
-#include <KUserFeedback/Provider>
 #include "kmail_export.h"
+#include <KUserFeedback/Provider>
 
 class KMAIL_EXPORT KMailUserFeedbackProvider : public KUserFeedback::Provider
 {
     Q_OBJECT
 public:
     explicit KMailUserFeedbackProvider(QObject *parent = nullptr);
-    ~KMailUserFeedbackProvider();
+    ~KMailUserFeedbackProvider() override;
 };
 
 #endif // KMAILUSERFEEDBACKPROVIDER_H
