@@ -7,20 +7,20 @@
 #include "util.h"
 #include "kmkernel.h"
 
-#include <MessageCore/StringUtil>
-#include <MessageComposer/MessageHelper>
 #include "job/handleclickedurljob.h"
+#include <MessageComposer/MessageHelper>
+#include <MessageCore/StringUtil>
 
-#include <kmime/kmime_message.h>
-#include <KLocalizedString>
 #include "kmail_debug.h"
+#include <KLocalizedString>
+#include <kmime/kmime_message.h>
 
 #include <QAction>
 #include <QStandardPaths>
 
 using namespace MailCommon;
 using namespace KMail;
-KMime::Types::Mailbox::List Util::mailingListsFromMessage(const Akonadi::Item &item)
+KMime::Types::Mailbox::List KMail::Util::mailingListsFromMessage(const Akonadi::Item &item)
 {
     KMime::Types::Mailbox::List addresses;
     // determine the mailing list posting address
@@ -37,7 +37,7 @@ KMime::Types::Mailbox::List Util::mailingListsFromMessage(const Akonadi::Item &i
     return addresses;
 }
 
-Akonadi::Item::Id Util::putRepliesInSameFolder(const Akonadi::Item &item)
+Akonadi::Item::Id KMail::Util::putRepliesInSameFolder(const Akonadi::Item &item)
 {
     Akonadi::Collection parentCollection = item.parentCollection();
     if (parentCollection.isValid()) {
@@ -49,10 +49,10 @@ Akonadi::Item::Id Util::putRepliesInSameFolder(const Akonadi::Item &item)
     return -1;
 }
 
-bool Util::handleClickedURL(const QUrl &url, const QSharedPointer<MailCommon::FolderSettings> &folder, const Akonadi::Collection &collection)
+bool KMail::Util::handleClickedURL(const QUrl &url, const QSharedPointer<MailCommon::FolderSettings> &folder, const Akonadi::Collection &collection)
 {
     if (url.scheme() == QLatin1String("mailto")) {
-        auto *job = new HandleClickedUrlJob;
+        auto job = new HandleClickedUrlJob;
         job->setUrl(url);
         job->setFolder(folder);
         job->setCurrentCollection(collection);
@@ -64,10 +64,9 @@ bool Util::handleClickedURL(const QUrl &url, const QSharedPointer<MailCommon::Fo
     }
 }
 
-bool Util::mailingListsHandleURL(const QList<QUrl> &lst, const QSharedPointer<MailCommon::FolderSettings> &folder, const Akonadi::Collection &collection)
+bool KMail::Util::mailingListsHandleURL(const QList<QUrl> &lst, const QSharedPointer<MailCommon::FolderSettings> &folder, const Akonadi::Collection &collection)
 {
-    const QString handler = (folder->mailingList().handler() == MailingList::KMail)
-                            ? QStringLiteral("mailto") : QStringLiteral("https");
+    const QString handler = (folder->mailingList().handler() == MailingList::KMail) ? QStringLiteral("mailto") : QStringLiteral("https");
 
     QUrl urlToHandle;
     QList<QUrl>::ConstIterator end(lst.constEnd());
@@ -89,53 +88,53 @@ bool Util::mailingListsHandleURL(const QList<QUrl> &lst, const QSharedPointer<Ma
     }
 }
 
-bool Util::mailingListPost(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
+bool KMail::Util::mailingListPost(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
 {
     if (fd) {
-        return Util::mailingListsHandleURL(fd->mailingList().postUrls(), fd, col);
+        return KMail::Util::mailingListsHandleURL(fd->mailingList().postUrls(), fd, col);
     }
     return false;
 }
 
-bool Util::mailingListSubscribe(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
+bool KMail::Util::mailingListSubscribe(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
 {
     if (fd) {
-        return Util::mailingListsHandleURL(fd->mailingList().subscribeUrls(), fd, col);
+        return KMail::Util::mailingListsHandleURL(fd->mailingList().subscribeUrls(), fd, col);
     }
     return false;
 }
 
-bool Util::mailingListUnsubscribe(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
+bool KMail::Util::mailingListUnsubscribe(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
 {
     if (fd) {
-        return Util::mailingListsHandleURL(fd->mailingList().unsubscribeUrls(), fd, col);
+        return KMail::Util::mailingListsHandleURL(fd->mailingList().unsubscribeUrls(), fd, col);
     }
     return false;
 }
 
-bool Util::mailingListArchives(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
+bool KMail::Util::mailingListArchives(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
 {
     if (fd) {
-        return Util::mailingListsHandleURL(fd->mailingList().archiveUrls(), fd, col);
+        return KMail::Util::mailingListsHandleURL(fd->mailingList().archiveUrls(), fd, col);
     }
     return false;
 }
 
-bool Util::mailingListHelp(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
+bool KMail::Util::mailingListHelp(const QSharedPointer<MailCommon::FolderSettings> &fd, const Akonadi::Collection &col)
 {
     if (fd) {
-        return Util::mailingListsHandleURL(fd->mailingList().helpUrls(), fd, col);
+        return KMail::Util::mailingListsHandleURL(fd->mailingList().helpUrls(), fd, col);
     }
     return false;
 }
 
-void Util::lastEncryptAndSignState(bool &lastEncrypt, bool &lastSign, const KMime::Message::Ptr &msg)
+void KMail::Util::lastEncryptAndSignState(bool &lastEncrypt, bool &lastSign, const KMime::Message::Ptr &msg)
 {
     lastSign = KMime::isSigned(msg.data());
     lastEncrypt = KMime::isEncrypted(msg.data());
 }
 
-void Util::addQActionHelpText(QAction *action, const QString &text)
+void KMail::Util::addQActionHelpText(QAction *action, const QString &text)
 {
     action->setStatusTip(text);
     action->setToolTip(text);
@@ -144,12 +143,12 @@ void Util::addQActionHelpText(QAction *action, const QString &text)
     }
 }
 
-void Util::setActionTrashOrDelete(QAction *action, bool isInTrashFolder)
+void KMail::Util::setActionTrashOrDelete(QAction *action, bool isInTrashFolder)
 {
     if (action) {
         action->setText(isInTrashFolder ? i18nc("@action Hard delete, bypassing trash", "&Delete") : i18n("&Move to Trash"));
         action->setIcon(isInTrashFolder ? QIcon::fromTheme(QStringLiteral("edit-delete-shred")) : QIcon::fromTheme(QStringLiteral("edit-delete")));
-        //Use same text as in Text property. Change it in kf5
+        // Use same text as in Text property. Change it in kf5
         action->setToolTip(isInTrashFolder ? i18nc("@action Hard delete, bypassing trash", "Delete") : i18n("Move to Trash"));
     }
 }
