@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,8 +12,7 @@
 class AgentIdentifier
 {
 public:
-    AgentIdentifier()
-    = default;
+    AgentIdentifier() = default;
 
     AgentIdentifier(const QString &identifier, const QString &name, int index = -1)
         : mIdentifier(identifier)
@@ -32,7 +31,7 @@ class KActionMenuAccount : public KActionMenu
     Q_OBJECT
 public:
     explicit KActionMenuAccount(QObject *parent = nullptr);
-    ~KActionMenuAccount();
+    ~KActionMenuAccount() override;
 
     void setAccountOrder(const QStringList &identifier);
 
