@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #include "vacationscriptindicatorwidget.h"
 
 #include "util.h"
-#include <QIcon>
 #include <KLocalizedString>
+#include <QIcon>
 
 #include <QHBoxLayout>
 
@@ -24,8 +24,7 @@ ServerLabel::ServerLabel(const QString &serverName, QWidget *parent)
     setContentsMargins(2, 0, 4, 0);
 }
 
-ServerLabel::~ServerLabel()
-= default;
+ServerLabel::~ServerLabel() = default;
 
 void ServerLabel::mouseReleaseEvent(QMouseEvent *event)
 {
@@ -43,8 +42,7 @@ VacationLabel::VacationLabel(const QString &text, QWidget *parent)
     setCursor(QCursor(Qt::PointingHandCursor));
 }
 
-VacationLabel::~VacationLabel()
-= default;
+VacationLabel::~VacationLabel() = default;
 
 void VacationLabel::mouseReleaseEvent(QMouseEvent *event)
 {
@@ -57,8 +55,7 @@ VacationScriptIndicatorWidget::VacationScriptIndicatorWidget(QWidget *parent)
 {
 }
 
-VacationScriptIndicatorWidget::~VacationScriptIndicatorWidget()
-= default;
+VacationScriptIndicatorWidget::~VacationScriptIndicatorWidget() = default;
 
 void VacationScriptIndicatorWidget::setVacationScriptActive(bool active, const QString &serverName)
 {
@@ -89,7 +86,7 @@ void VacationScriptIndicatorWidget::createIndicator()
     connect(mInfo, &VacationLabel::vacationLabelClicked, this, &VacationScriptIndicatorWidget::slotVacationLabelClicked);
     mBoxLayout->addWidget(mInfo);
     for (const QString &server : qAsConst(mServerActive)) {
-        auto *lab = new ServerLabel(server);
+        auto lab = new ServerLabel(server);
         connect(lab, &ServerLabel::clicked, this, &VacationScriptIndicatorWidget::clicked);
         mBoxLayout->addWidget(lab);
     }
